@@ -167,9 +167,15 @@ class TemplateTest extends TestCase
 
         $this->assertSame('Zero', $array[false]);
         $this->assertSame('One', $array[true]);
-        $this->assertSame('One', $array[1.5]);
+        if (\PHP_VERSION_ID < 80100) {
+            // This line will trigger a deprecation warning on PHP 8.1.
+            $this->assertSame('One', $array[1.5]);
+        }
         $this->assertSame('One', $array['1']);
-        $this->assertSame('MinusOne', $array[-1.5]);
+        if (\PHP_VERSION_ID < 80100) {
+            // This line will trigger a deprecation warning on PHP 8.1.
+            $this->assertSame('MinusOne', $array[-1.5]);
+        }
         $this->assertSame('FloatButString', $array['1.5']);
         $this->assertSame('IntegerButStringWithLeadingZeros', $array['01']);
         $this->assertSame('EmptyString', $array[null]);
@@ -471,21 +477,25 @@ class TemplateArrayAccessObject implements \ArrayAccess
         '+4' => '+4',
     ];
 
-    public function offsetExists($name)
+    public function offsetExists($name) : bool
     {
         return \array_key_exists($name, $this->attributes);
     }
 
+    /**
+     * @return mixed
+     */
+    #[\ReturnTypeWillChange]
     public function offsetGet($name)
     {
         return \array_key_exists($name, $this->attributes) ? $this->attributes[$name] : null;
     }
 
-    public function offsetSet($name, $value)
+    public function offsetSet($name, $value) : void
     {
     }
 
-    public function offsetUnset($name)
+    public function offsetUnset($name) : void
     {
     }
 }
@@ -508,7 +518,7 @@ class TemplateMagicPropertyObject
 
     protected $protected = 'protected';
 
-    public function __isset($name)
+    public function __isset($name): bool
     {
         return \array_key_exists($name, $this->attributes);
     }
@@ -521,7 +531,7 @@ class TemplateMagicPropertyObject
 
 class TemplateMagicPropertyObjectWithException
 {
-    public function __isset($key)
+    public function __isset($key): bool
     {
         throw new \Exception('Hey! Don\'t try to isset me!');
     }
@@ -542,7 +552,7 @@ class TemplatePropertyObject
 
 class TemplatePropertyObjectAndIterator extends TemplatePropertyObject implements \IteratorAggregate
 {
-    public function getIterator()
+    public function getIterator(): \Traversable
     {
         return new \ArrayIterator(['foo', 'bar']);
     }
@@ -560,21 +570,25 @@ class TemplatePropertyObjectAndArrayAccess extends TemplatePropertyObject implem
         'baf' => 'baf',
     ];
 
-    public function offsetExists($offset)
+    public function offsetExists($offset) : bool
     {
         return \array_key_exists($offset, $this->data);
     }
 
+    /**
+     * @return mixed
+     */
+    #[\ReturnTypeWillChange]
     public function offsetGet($offset)
     {
         return $this->offsetExists($offset) ? $this->data[$offset] : 'n/a';
     }
 
-    public function offsetSet($offset, $value)
+    public function offsetSet($offset, $value) : void
     {
     }
 
-    public function offsetUnset($offset)
+    public function offsetUnset($offset) : void
     {
     }
 }
@@ -708,22 +722,26 @@ class TemplateArrayAccess implements \ArrayAccess
     ];
     private $children = [];
 
-    public function offsetExists($offset)
+    public function offsetExists($offset) : bool
     {
         return \array_key_exists($offset, $this->children);
     }
 
+    /**
+     * @return mixed
+     */
+    #[\ReturnTypeWillChange]
     public function offsetGet($offset)
     {
         return $this->children[$offset];
     }
 
-    public function offsetSet($offset, $value)
+    public function offsetSet($offset, $value) : void
     {
         $this->children[$offset] = $value;
     }
 
-    public function offsetUnset($offset)
+    public function offsetUnset($offset) : void
     {
         unset($this->children[$offset]);
     }
